diff --git a/atlassian-connect-core.cabal b/atlassian-connect-core.cabal
--- a/atlassian-connect-core.cabal
+++ b/atlassian-connect-core.cabal
@@ -10,7 +10,7 @@
 -- PVP summary:      +-+------- breaking API changes
 --                   | | +----- non-breaking API additions
 --                   | | | +--- code changes with no API change
-version:             0.7.1.0
+version:             0.7.2.0
 
 -- A short (one-line) description of the package.
 synopsis:            Atlassian Connect snaplet for the Snap Framework and helper code.
diff --git a/src/Snap/AtlassianConnect/Tenant.hs b/src/Snap/AtlassianConnect/Tenant.hs
--- a/src/Snap/AtlassianConnect/Tenant.hs
+++ b/src/Snap/AtlassianConnect/Tenant.hs
@@ -23,10 +23,11 @@
 -- | Represents an Atlassian Cloud tenant. Your Atlassian Connect add-on can be installed into multiple Atlassian
 -- Cloud tenants.
 data Tenant = Tenant
-   { tenantId     :: Integer     -- ^ Your identifier for this tenant.
-   , key          :: TenantKey   -- ^ The unique identifier for this tenant accross Atlassian Connect.
-   , publicKey    :: T.Text      -- ^ The public key for this atlassian connect application.
-   , sharedSecret :: T.Text      -- ^ The shared secret for this atlassian connect application. Used for JWT token generation.
-   , baseUrl      :: ConnectURI  -- ^ The base url of the Atlassian Cloud host application (product).
-   , productType  :: T.Text      -- ^ The type of product you have connected to in the Atlassian Cloud. (E.g. JIRA, Confluence)
+   { tenantId      :: Integer       -- ^ Your identifier for this tenant.
+   , key           :: TenantKey     -- ^ The unique identifier for this tenant accross Atlassian Connect.
+   , publicKey     :: T.Text        -- ^ The public key for this atlassian connect application.
+   , oauthClientId :: Maybe T.Text  -- ^ The OAuth Client Id for this tenant. If this add-on does not support user impersonation then this may not be present.
+   , sharedSecret  :: T.Text        -- ^ The shared secret for this atlassian connect application. Used for JWT token generation.
+   , baseUrl       :: ConnectURI    -- ^ The base url of the Atlassian Cloud host application (product).
+   , productType   :: T.Text        -- ^ The type of product you have connected to in the Atlassian Cloud. (E.g. JIRA, Confluence)
    } deriving (Eq, Show, Generic)
